@@ -37,7 +37,7 @@ from click_extra.platform import CURRENT_OS_ID, is_linux
 from click_extra.run import INDENT, format_cli, run_cmd
 
 from . import logger
-from .version import parse_version
+from .version import TokenizedString, parse_version
 
 
 class CLIError(Exception):
@@ -126,21 +126,21 @@ class PackageManager:
 
     Should be a list of strings whose order dictatate the search sequence.
 
-    Most of the time unnecessay: :py:func:`meta_package_manager.base.PackageManager.cli_path`
+    Most of the time unnecessary: :py:func:`meta_package_manager.base.PackageManager.cli_path`
     works well on all platforms.
     """
 
     extra_env = None
     """Additional environment variables to add to the current context.
 
-    Automaticcaly applied on each :py:func:`meta_package_manager.base.PackageManager.run_cli`
+    Automatically applied on each :py:func:`meta_package_manager.base.PackageManager.run_cli`
     calls.
     """
 
     pre_cmds = ()
     """Global list of pre-commands to add before before invoked CLI.
 
-    Automaticcaly added to each :py:func:`meta_package_manager.base.PackageManager.run_cli`
+    Automatically added to each :py:func:`meta_package_manager.base.PackageManager.run_cli`
     call.
 
     Used to prepend `sudo <https://www.sudo.ws>`_ or other system utilities.
@@ -150,7 +150,7 @@ class PackageManager:
     post_args = ()
     """Global list of options used before and after the invoked package manager CLI.
 
-    Automaticcaly added to each :py:func:`meta_package_manager.base.PackageManager.run_cli`
+    Automatically added to each :py:func:`meta_package_manager.base.PackageManager.run_cli`
     call.
 
     Essentially used to force silencing, low verbosity or no-color output.
@@ -172,7 +172,7 @@ class PackageManager:
     """Tell the manager to either raise or continue on errors."""
 
     ignore_auto_updates = True
-    """Some managers can report or ignore packages which have their own auto-update mecanism.
+    """Some managers can report or ignore packages which have their own auto-update mechanism.
     """
 
     dry_run = False
@@ -195,7 +195,7 @@ class PackageManager:
     def cli_path(self):
         """Fully qualified path to the package manager CLI.
 
-        Automaticaly search the location of the CLI in the system. Try multiple CLI
+        Automatically search the location of the CLI in the system. Try multiple CLI
         names within several system path.
 
         Only checks if the file exists. Its executability will be assessed later. See
@@ -327,7 +327,7 @@ class PackageManager:
 
     @classmethod
     def args_cleanup(cls, *args):
-        """Flatten recusive iterables, remove all ``None``, and cast each element to
+        """Flatten recursive iterables, remove all ``None``, and cast each element to
         strings.
 
         Helps serialize :py:class:`pathlib.Path` and :py:class:`meta_package_manager.version.TokenizedString` objects.
@@ -437,7 +437,7 @@ class PackageManager:
         * ``override_pre_args=tuple()``
         * ``override_post_args=tuple()``
 
-        On linux, the command can be ran with `sudo <https://www.sudo.ws>`_ if the parameter of the same name is set to ``True``.
+        On linux, the command can be run with `sudo <https://www.sudo.ws>`_ if the parameter of the same name is set to ``True``.
         In which case the ``override_pre_cmds`` parameter is not allowed to be set and the ``auto_pre_cmds`` parameter is forced to ``False``.
         """
         params = []
@@ -604,6 +604,30 @@ class PackageManager:
         """
         raise NotImplementedError
 
+    def refilter(self, results, query, extended, exact):
+        """Manually refilters search results against ``extended`` and ``exact``
+        parameters.
+
+        Some package managers returns unbounded search results, and don't support finer
+        search criterions. In which case we consider the results as extended by default,
+        and use this method to manually refilters results to either exclude non-extended
+        or non-exact matches.
+        """
+        for package_id, version, description in results:
+
+            # Exclude packages not featuring the search query in their ID or name.
+            if not extended:
+                query_parts = set(map(str, TokenizedString(query)))
+                pkg_parts = set(map(str, TokenizedString(package_id)))
+                if not query_parts.issubset(pkg_parts):
+                    continue
+
+            # Filters out fuzzy matches, only keep stricly matching packages.
+            if exact and query != package_id:
+                continue
+
+            yield package_id, version, description
+
     def search(self, query, extended, exact):
         """Search packages available for install.
 
@@ -666,7 +690,7 @@ class PackageManager:
         one returned by :py:meth:`meta_package_manager.base.PackageManager.upgrade_cli`.
 
         It can also be used to ``raise NotImplementedError`` on some managers to signal to :program:`mpm` that
-        the package manager has no proper support for a full upgrade command. See for example
+        the package manager has no proper support for a full upgrade operation. See for example
         :py:meth:`meta_package_manager.managers.pip.Pip.upgrade_all_cli`.
         """
         return self.upgrade_cli()
@@ -685,9 +709,9 @@ class PackageManager:
         try:
             return self.run(self.upgrade_all_cli(), extra_env=self.extra_env)
         except NotImplementedError:
-            logger.warning(f"{self.id} does not implement upgrade_all command.")
+            logger.warning(f"{self.id} does not implement upgrade_all operation.")
 
-        logger.info(f"Fallback to calling single-package upgrade one by one.")
+        logger.info(f"Fallback to calling upgrade operation on each outdated package.")
         log = ""
         for package_id in self.outdated:
             output = self.upgrade(package_id)
