@@ -66,9 +66,7 @@ class Homebrew(PackageManager):
 
     @property
     def installed(self):
-        """List installed packages from ``brew list`` output.
-
-        Raw CLI output samples:
+        """Fetch installed packages.
 
         .. code-block:: shell-session
 
@@ -98,7 +96,7 @@ class Homebrew(PackageManager):
             tunnelblick 3.6.8_build_4625 3.6.9_build_4685
             virtualbox 5.1.8-111374 5.1.10-112026
 
-        .. todo
+        .. todo::
 
             Use the ``removed`` variable to detect removed packages (which are
             reported with a ``(!)`` flag). See:
@@ -118,16 +116,15 @@ class Homebrew(PackageManager):
                 installed[package_id] = {
                     "id": package_id,
                     "name": package_id,
-                    "installed_version":
                     # Keep highest version found.
-                    max(map(parse_version, versions.split())),
+                    "installed_version": max(map(parse_version, versions.split())),
                 }
 
         return installed
 
     @property
     def outdated(self):
-        """Fetch outdated packages from ``brew outdated`` output.
+        """Fetch outdated packages.
 
         .. code-block:: shell-session
 
@@ -243,7 +240,7 @@ class Homebrew(PackageManager):
         return outdated
 
     def search(self, query, extended, exact):
-        """Fetch matching packages from ``brew search`` output.
+        """Fetch matching packages.
 
         .. code-block:: shell-session
 
@@ -348,12 +345,11 @@ class Homebrew(PackageManager):
             ==> Moving App 'Pngyu.app' to '/Applications/Pngyu.app'
             🍺  pngyu was successfully installed!
         """
-        super().install(package_id)
         return self.run_cli("install", package_id)
 
     def upgrade_cli(self, package_id=None):
-        """Returns the right CLI depending on weither formula or cask are
-        concerned:
+        """Generates the CLI to upgrade all packages (default) or only the one provided
+        as parameter.
 
         ``brew`` and ``cask`` share the same command.
 
@@ -419,24 +415,22 @@ class Homebrew(PackageManager):
             ==> Purging files for version 4.2.0 of Cask dupeguru
             🍺  dupeguru was successfully upgraded!
         """
-        return self.build_cli(
-            "upgrade",
-            package_id,
-        )
+        return self.build_cli("upgrade", package_id)
 
     def sync(self):
-        """Fetch content of remote taps.
+        """Sync package metadata.
 
         .. code-block:: shell-session
 
             ► brew update --quiet
             Already up-to-date.
         """
-        super().sync()
         self.run_cli("update", "--quiet", auto_post_args=False)
 
     def cleanup(self):
-        """Scrub the cache, including latest version's downloads. Also remove unused
+        """Removes things we don't need anymore.
+
+        Scrub the cache, including latest version's downloads. Also remove unused
         dependencies.
 
         Downloads for all installed formulae and casks will not be deleted.
@@ -477,7 +471,6 @@ class Homebrew(PackageManager):
             Uninstalling /usr/local/Cellar/lua@5.1/5.1.5_8... (22 files, 245.6KB)
             Uninstalling /usr/local/Cellar/nasm/2.15.05... (29 files, 2.9MB)
         """
-        super().cleanup()
         self.run_cli("autoremove", auto_post_args=False)
         self.run_cli("cleanup", "-s", "--prune=all", auto_post_args=False)
 
