@@ -21,7 +21,7 @@ import re
 from click_extra.platform import LINUX, MACOS, WINDOWS
 
 from ..base import PackageManager
-from ..version import TokenizedString, parse_version
+from ..version import parse_version
 
 
 class Pip(PackageManager):
@@ -204,6 +204,9 @@ class Pip(PackageManager):
             API because of unmanageable high-load. See:
             https://github.com/pypa/pip/issues/5216#issuecomment-744605466
 
+        .. caution:
+            Search is extended by default, results are manually refiltered.
+
         .. code-block:: shell-session
 
             ► python -m pip --no-color search abc
@@ -236,20 +239,9 @@ class Pip(PackageManager):
             re.MULTILINE | re.VERBOSE,
         )
 
-        for package_id, version, description in regexp.findall(output):
-
-            # Exclude packages not featuring the search query in their ID
-            # or name.
-            if not extended:
-                query_parts = set(map(str, TokenizedString(query)))
-                pkg_parts = set(map(str, TokenizedString(package_id)))
-                if not query_parts.issubset(pkg_parts):
-                    continue
-
-            # Filters out fuzzy matches, only keep stricly matching
-            # packages.
-            if exact and query != package_id:
-                continue
+        for package_id, version, description in self.refilter(
+            regexp.findall(output), query, extended, exact
+        ):
 
             matches[package_id] = {
                 "id": package_id,
