@@ -46,6 +46,7 @@ class TestInstall(CLISubCommandTests):
         "apt": "wget",
         "apt-mint": "exiftool",
         "brew": "jpeginfo",
+        "cargo": "colorous",
         "cask": "pngyu",
         "choco": "ccleaner",
         "composer": "illuminate/contracts",
@@ -58,8 +59,9 @@ class TestInstall(CLISubCommandTests):
         "opkg": "enigma2-hotplug",
         "pacman": "manjaro-hello",
         "pip": "arrow",
+        "pipx": "pycowsay",
         "snap": "standard-notes",
-        "steamcmd": "",
+        "steamcmd": "740",
         "vscode": "tamasfe.even-better-toml",
         "yarn": "markdown",
         "yum": "usd",
@@ -72,7 +74,7 @@ class TestInstall(CLISubCommandTests):
         "mid,package_id", (pytest.param(*v, id=v[0]) for v in PACKAGE_IDS.items())
     )
     def test_single_manager_install(self, invoke, mid, package_id):
-        result = invoke("--manager", mid, "install", package_id)
+        result = invoke(f"--{mid}", "install", package_id)
         assert result.exit_code == 0
         self.check_manager_selection(result, {mid}, reference_set=pool.all_manager_ids)
 
